==> haskell-src-meta-0.8.0.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.8.0.1
id: haskell-src-meta-0.8.0.1-EZFogQheEfqD9CELSTnSfp
key: haskell-src-meta-0.8.0.1-EZFogQheEfqD9CELSTnSfp
license: BSD3
copyright: (c) Matt Morrow
maintainer: Ben Millwood <haskell@benmachine.co.uk>
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Syntax.Translate Language.Haskell.Meta.Utils
abi: f84cd73c8335bc09440f02d1a21270ad
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/haskell-src-meta-0.8.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/haskell-src-meta-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/haskell-src-meta-0.8.0.1
hs-libraries: HShaskell-src-meta-0.8.0.1-EZFogQheEfqD9CELSTnSfp
depends:
    base-4.9.1.0 haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    pretty-1.1.3.3 syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
    template-haskell-2.11.1.0 th-orphans-0.13.3-1N7FgGBrfp4F9N2gYS687g
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.0.1-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.8.0.1
id: haskell-src-meta-0.8.0.1-JSDsejh0M8Q9uvnP5X7pLR
key: haskell-src-meta-0.8.0.1-JSDsejh0M8Q9uvnP5X7pLR
license: BSD3
copyright: (c) Matt Morrow
maintainer: Ben Millwood <haskell@benmachine.co.uk>
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Syntax.Translate Language.Haskell.Meta.Utils
abi: 683c1cb0d4741bb35f3a2fff60f56d80
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/haskell-src-meta-0.8.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/haskell-src-meta-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/haskell-src-meta-0.8.0.1
hs-libraries: HShaskell-src-meta-0.8.0.1-JSDsejh0M8Q9uvnP5X7pLR
depends:
    base-4.9.1.0 haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    pretty-1.1.3.3 syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
    template-haskell-2.11.1.0 th-orphans-0.13.4-2cESVTBijbz3HdUeN6yr6k
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
